@@ -11,7 +11,7 @@ from .plot import plot_spec
 
 
 class FPCross:
-    def __init__(self, eq, with_hist=False):
+    def __init__(self, eq, with_hist=False, with_y_list=False, with_a_list=False):
         """Class that represents the solver for the Fokker-Planck equation.
 
         Args:
@@ -19,6 +19,11 @@ class FPCross:
             with_hist (bool): if flag is set, then accuracy of the result will
                 be checked after each time step. Otherwise, the accuracy check
                 will be performed only after the solver has finished running.
+            with_y_list (bool): if flag is set, then solutions from each time
+                step will be saved in "Y_list" variable.
+            with_a_list (bool): if flag is set, then interpoltation
+                coefficients of the solutions from each time step will be saved
+                in "A_list" variable.
 
         """
         self.eq = eq
@@ -33,6 +38,8 @@ class FPCross:
         self.s = None  # Current value of Y integral over the spatial domain
         self.t = 0.    # Current value of the time variable
         self.tc = 0.   # Computation time (duration of solver work)
+
+        # Special varuables:
         self.is_last = False
 
         # History for errors, ranks ant integral while computation proccess:
@@ -41,6 +48,12 @@ class FPCross:
         self.r_list = []
         self.s_list = []
 
+        # History for solutions from each time step:
+        self.with_y_list = bool(with_y_list)
+        self.Y_list = []
+        self.with_a_list = bool(with_a_list)
+        self.A_list = []
+
     def get(self, X):
         """Calculate the current solution in the given spatial point.
 
@@ -61,10 +74,8 @@ class FPCross:
         if is_one:
             X = X.reshape(1, -1)
 
-        if self.is_full:
-            y = teneva.cheb_get_full(X, self.A, self.eq.a, self.eq.b)
-        else:
-            y = teneva.cheb_get(X, self.A, self.eq.a, self.eq.b)
+        func = teneva.cheb_get_full if self.is_full else teneva.cheb_get
+        y = func(X, self.A, self.eq.a, self.eq.b)
 
         return y[0] if is_one else y
 
@@ -90,7 +101,7 @@ class FPCross:
         for m in range(1, self.eq.m + 1):
             self.m = m
             self.t = self.eq.h * self.m
-            self.is_last = m == self.eq.m
+            self.is_last = (m == self.eq.m)
 
             self._step()
             self._step_proc()
@@ -126,7 +137,12 @@ class FPCross:
         self.text += f' | e_t={e:-8.2e}'
         return e
 
-    def _conv_apply(self):
+    def _conv_apply(self, n_fine_fact=None):
+        if n_fine_fact is not None and not self.is_full:
+            # Experimental option!! Should be "None" in actual code
+            n_fine = self.eq.n * n_fine_fact
+            Z = teneva.cheb_gets(self.A, self.eq.a, self.eq.b, n_fine)
+
         def func(y, t):
             X, r = y[:, :-1], y[:, -1]
             f0 = self.eq.f(X, self.t)
@@ -141,7 +157,12 @@ class FPCross:
             if self.is_full:
                 w0 = teneva.cheb_get_full(X0, self.A, self.eq.a, self.eq.b)
             else:
-                w0 = teneva.cheb_get(X0, self.A, self.eq.a, self.eq.b)
+                if n_fine_fact is None:
+                    w0 = teneva.cheb_get(X0, self.A, self.eq.a, self.eq.b)
+                else:
+                    I0 = teneva.poi_to_ind(X0,
+                        self.eq.a, self.eq.b, n_fine, 'cheb')
+                    w0 = teneva.get_many(Z, I0)
 
             y0 = np.hstack([X0, w0.reshape(-1, 1)])
 
@@ -165,9 +186,10 @@ class FPCross:
             self.Y = teneva.truncate(self.Y, self.eq.e)
 
     def _diff_init(self):
-        D1, D2 = diff_matrices(2, self.eq.n[0], self.eq.a[0], self.eq.b[0])
+        n = self.eq.n[0]
+        D1, D2 = teneva.cheb_diff_matrix(self.eq.a[0], self.eq.b[0], n, 2)
         h0 = self.eq.h / 2
-        J0 = np.eye(self.eq.n[0])
+        J0 = np.eye(n)
         J0[+0, +0] = 0.
         J0[-1, -1] = 0.
         self.Z = expm(h0 * self.eq.coef * J0 @ D2)
@@ -207,6 +229,13 @@ class FPCross:
         self._interpolate()
         self.tc += tpc() - tc
 
+        if self.with_y_list:
+            Y = self.Y.copy() if self.is_full else teneva.copy(self.Y)
+            self.Y_list.append(Y)
+        if self.with_a_list:
+            A = self.A.copy() if self.is_full else teneva.copy(self.A)
+            self.A_list.append(A)
+
     def _step_init(self):
         tc = tpc()
         self._diff_init()
@@ -229,39 +258,6 @@ class FPCross:
         self.s_list.append(self.s)
 
 
-def diff_matrices(m, n, l_min, l_max):
-    n1 = np.int(np.floor(n / 2))
-    n2 = np.int(np.ceil(n / 2))
-    k = np.arange(n)
-    th = k * np.pi / (n - 1)
-
-    T = np.tile(th/2, (n, 1))
-    DX = 2. * np.sin(T.T + T) * np.sin(T.T - T)
-    DX[n1:, :] = -np.flipud(np.fliplr(DX[0:n2, :]))
-    DX[range(n), range(n)] = 1.
-    DX = DX.T
-
-    Z = 1. / DX
-    Z[range(n), range(n)] = 0.
-
-    C = toeplitz((-1.)**k)
-    C[+0, :]*= 2
-    C[-1, :]*= 2
-    C[:, +0]*= 0.5
-    C[:, -1]*= 0.5
-
-    D_list = []
-    D = np.eye(n)
-    l = 2. / (l_max - l_min)
-    for i in range(m):
-        D = (i + 1) * Z * (C * np.tile(np.diag(D), (n, 1)).T - D)
-        D[range(n), range(n)] = -np.sum(D, axis=1)
-        D_list.append(D * l)
-        l = l * l
-
-    return D_list
-
-
 def ode_solve(f, y0, t, n, h):
     y = y0.copy()
     for _ in range(1, n):
